#!/bin/sh
#
# Automatically mount first partition to /mnt/C, /mnt/D, /mnt/E, ...
# 
# Gil Jin Yang, gjyang@seyeon.co.kr

source /etc/profile

STORAGE_INFO_LOG_FILE="/var/log/storage.info.log"
function log() {
	LOG_FILE=${STORAGE_INFO_LOG_FILE}
	touch $LOG_FILE
	log_file_size=`ls -al ${LOG_FILE} | awk '{printf $5}'`
	if [ "$log_file_size" != "" ]; then 
		if [ $log_file_size -ge 262144 ]; then
			rm $LOG_FILE
			touch $LOG_FILE
			echo "[`date`] ${THIS_SH} $*" > $LOG_FILE
		else
			echo "[`date`] ${THIS_SH} $*" >> $LOG_FILE
		fi
	fi
}

SDCARD_ERROR="1100"
NEED_FORMAT="1101"
SDCARD_MOUNT="1200"
SDCARD_UNMOUNT="1300"
EVENT_SEND_EXEC="/opt/nss/bin/post_event_alarm"
mopts='errors=remount-ro,relatime,noatime,nodiratime'

function post_event(){
	_dir=$1
	_node=$2
	_evt_code=$3
	if [ "$_dir" == "/mnt/C" -a "`echo $_node | rev | cut -c 1`" == "1" ]; then 
		if [ -x $EVENT_SEND_EXEC ]; then 
			log "post_event  $_dir $_node $_evt_code"
			log "$EVENT_SEND_EXEC $_evt_code"
			$EVENT_SEND_EXEC $_evt_code &
		fi
	fi
}

function check_device() {
	# Check if the device exists, if not but mounted, umount it
	chk_dev=$1
	if ! [ -b $chk_dev ]
	then
		if grep /etc/mtab -qe "^$chk_dev"
		then
			mounted=`cat /etc/mtab |grep $chk_dev | awk '{printf $2}'`
			log "Device $chk_dev is removed, umounting and cleaning ${mounted}"
			umount -l "$mounted"
			log "umount: exitcode=$?"
			post_event "${mounted}" "${chk_dev}" "${SDCARD_UNMOUNT}"
			exitcode=$?
		else
			log "Device $chk_dev doesn't exist anymore"
			post_event "${mounted}" "${chk_dev}" "${SDCARD_UNMOUNT}"
			exitcode=0
		fi

		exit $exitcode
	else
		if blkid -po export $chk_dev 2>&1 | grep -q "No medium found"
		then
			for medium in $(find /dev -name "${chk_dev##*/}[0-9]*")
			do
				mountpoint=$(grep /etc/mtab -e "^${medium}" | awk '{print $2}')
				log "Unmounting device ${medium} from ${mountpoint}"
				log "mountpoint -q ${mountpoint}"
				umount -l "${medium}" && ! mountpoint -q ${mountpoint} 
				post_event "${mounted}" "${chk_dev}" "${SDCARD_UNMOUNT}"
			done
			exit 0
		fi
	fi
}


THIS_SH=`basename $0`
if ! [ "$1" ]; then
	log "missing arguments! a device name must be provided"
	exit 1
else
	DEVNAME=/dev/${1##*/}
	echo "$THIS_SH $DEVNAME"
fi


check_device $DEVNAME
eval "$(udevadm info -q property --export -p $(udevadm info -qpath -n ${DEVNAME}))";

if [ "$ID_BUS" != "usb" ]; then
	exit 0
fi

# DEC to ASCII 
chr() {
	[ "$1" -lt 256 ] || return 1 
	printf "\\$(printf '%03o' "$1")"
}
# ASCII to DEC   
ord() {
	LC_CTYPE=C printf '%d' "'$1"
}
set_cfg_env() {
# USAGE: <file> <environment> <value>
	CFG_FILE=$1
	ENV=$2
	ENV_VALUE=$3
	OLD_ENV=`grep "^${ENV}\=" $CFG_FILE`

	if [ "$OLD_ENV" != "" ]; then
		# edit env value to new one
		OLD_ENV=`echo $OLD_ENV | sed s,/,\\\\\\\\\\/,g`
		ENV_VALUE=`echo $ENV_VALUE | sed s,/,\\\\\\\\\\/,g`
		NEW_ENV="$ENV=$ENV_VALUE"
		sed -i -- "s/${ENV}=.*/$NEW_ENV/g" $CFG_FILE
	else
		# create new environment
		NEW_ENV="$ENV=$ENV_VALUE"
		echo "$NEW_ENV" >> $CFG_FILE
	fi
}

function check_firmware_file() {
	USB_MNT_DIR="/mnt/D"
	LATEST_FIRMWARE=`ls -A ${USB_MNT_DIR} | grep rf | sort | tail -n 1`
	# log "${LINENO} $0"
	if [ "$LATEST_FIRMWARE" != "" ]; then
		# log "${LINENO} $0"
		/opt/nss/bin/copy_n_fwupdate.sh "/mnt/D/${LATEST_FIRMWARE}" &
	fi
	# log "${LINENO} $0"
	return 0;
}

mount_dev(){
	devname=$1
	mountdir=$2
	fstype=$3
	log "(${LINENO}) $devname $mountdir $fstype"
	if [ "${devname}" == "" -o "${mountdir}" == "" -o "${fstype}" == "" ]; then
		exit 0;
	fi
	# create the mountpoint directory in /mnt/ (if not empty)
	mkdir -p ${mountdir}
	check_mount=`cat /proc/mounts | grep ${devname} | awk '{printf $2}'`
	if [ "$check_mount" != "" ]; then
		log "check_mount=${check_mount}"
		if [ "$check_mount" == "$mountdir" ]; then 
			log "(${LINENO}) already mounted on $mountdir"
			return 5;
		fi
	else
		log "check_mount=${check_mount}, null"
	fi

	if mount -t "${fstype:-auto}" -o "$mopts" "$devname" "$mountdir"
	then
		OEM_PN_CODE=`syft.st -r 1 | awk -F ' = ' '{printf $2}'| cut -c 30-31`
		if [ "$OEM_PN_CODE" != "1B" ]; then
			mkdir -p $mountdir/fimage
		fi
		check_firmware_file;
		log "Device $devname successfully mounted on $mountdir"
		return 0
	else
		log "Mount error: $?"
		return 1
	fi
	return 0;
}

if [ "$ID_PART_ENTRY_NUMBER" == "" ]; then
	exit 0;
fi

DEV_MODEL=`/usr/bin/udevadm info -q all -n ${DEVNAME} | /bin/grep ID_MODEL=| /usr/bin/awk -F '=' '{print $2}'`
if [ $ID_PART_ENTRY_NUMBER -eq 1 ]; then

	DEVNODE=`echo "$DEVNAME" | cut -c 6-`
	HDDNODE=`echo $DEVNODE | sed 's/[0-9]*//g'`
	PART_SIZE=`lsblk -l | grep "^$DEVNODE" | awk '{ print $4 }'`

	if [ "$DEV_MODEL" == "STORAGE_DEVICE" ]; then
		# USB to MicroSD chip
		PORT_NUM=0
	else
		# else (Currently support 1 USB device)
		PORT_NUM=1
	fi
	
	MNT_NODE_NAME=`chr $(($PORT_NUM+67))`
	MNT_BASE_DIR=/mnt
	MNT_DIR=$MNT_BASE_DIR/$MNT_NODE_NAME

	log "($LINENO) $DEVNAME:$MNT_DIR"
	# HDD Configuration for Web Admin
	PORT_NUM_2DIGIT=`printf '%02d' $PORT_NUM`
	STORAGE_INFO_FILE="/var/log/storage${PORT_NUM_2DIGIT}.info" 
	ENV_NAME=`printf 'HDD%02d' $PORT_NUM`
	if [ "$ID_PART_TABLE_TYPE" != "" ]; then
		PARTITION_TABLE=$ID_PART_TABLE_TYPE
	elif [ "$ID_PART_ENTRY_SCHEME" != "" ]; then
		PARTITION_TABLE=$ID_PART_ENTRY_SCHEME
	else
		PARTITION_TABLE="unknown"
	fi
	touch $STORAGE_INFO_FILE

	set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}DEV" $DEVNAME
	set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}PARTED" 1
	set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}PART_TABLE_TYPE" $PARTITION_TABLE
	set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}FSTYPE" $ID_FS_TYPE
	set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}UUID" $ID_FS_UUID
	set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}MNT" $MNT_DIR

	if [ "$PART_SIZE" != "" ]; then
		set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}SIZE" $PART_SIZE
	fi
	if [ "$ID_FS_TYPE" == "" ]; then
		set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}FORMAT" 0
		log "[ERROR] ID_FS_TYPE='$ID_FS_TYPE': Need to format"
		post_event "${MNT_DIR}" "${DEVNAME}" "$NEED_FORMAT"
		exit -1;
	elif [ "$ID_FS_TYPE" == "vfat" ]; then 
		mopts="$mopts,rw,nosuid,nodev,relatime,utf8"
		set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}FORMAT" 1
	elif [ "$ID_FS_TYPE" == "exfat" ]; then 
		mopts="$mopts,rw,nosuid,nodev,relatime,utf8,blksize=4096"
		set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}FORMAT" 1
	else
		# NEED_FORMAT
		# wrong file system skip mount procedure
		log "[ERROR] ID_FS_TYPE='$ID_FS_TYPE': Need to format"
		set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}FORMAT" -1
		post_event "${MNT_DIR}" "${DEVNAME}" "$NEED_FORMAT"
		exit -1;
	fi
	if [ "$ID_PART_TABLE_TYPE" != "dos" ]; then
		# NEED_FORMAT
		log "[ERROR] ID_PART_TABLE_TYPE='$ID_PART_TABLE_TYPE': Need to format"
		set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}FORMAT" -1
		post_event "${MNT_DIR}" "${DEVNAME}" "$NEED_FORMAT"
		exit -1;
	fi
	MOUNTED_DIR=`lsblk -l | awk '{ print $7 }'|grep $DEVNODE`
	if [ "$MOUNTED_DIR" == "" ]; then
		mount_dev $DEVNAME $MNT_DIR $ID_FS_TYPE >> ${STORAGE_INFO_LOG_FILE}
		RET=$?
		if [ $RET -eq 0 ]; then
			set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}MOUNTED" 1
			post_event "${MNT_DIR}" "${DEVNAME}" "$SDCARD_MOUNT"
		elif [ $RET -eq 5 ]; then
			# already mounted
			set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}MOUNTED" 1
		else
			log "${LINENO} [ERROR] mount_dev $DEVNAME $MNT_DIR $ID_FS_TYPE, RET=$RET"
			post_event "${MNT_DIR}" "${DEVNAME}" "$SDCARD_ERROR"
		fi
	else # $DEVNAME was already mounted to $MOUNTED_DIR
		echo "$THIS_SH: $DEVNAME was already mounted to $MOUNTED_DIR remount $DEVNAME to $MNT_DIR" >> ${STORAGE_INFO_LOG_FILE}
		if [ "$MOUNTED_DIR" != "$MNT_DIR" ]; then
			mount_dev $DEVNAME $MNT_DIR $ID_FS_TYPE >> ${STORAGE_INFO_LOG_FILE}
			RET=$?
			if [ $RET -eq 0 ]; then
				post_event "${MNT_DIR}" "${DEVNAME}" "$SDCARD_MOUNT"
				set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}MOUNTED" 1
			elif [ $RET -eq 5 ]; then
				# already mounted
				set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}MOUNTED" 1
			else
				log "${LINENO} [ERROR] mount_dev $DEVNAME $MNT_DIR $ID_FS_TYPE, RET=$RET"
				post_event "${MNT_DIR}" "${DEVNAME}" "$SDCARD_ERROR"
			fi
			umount -v $MOUNTED_DIR >> ${STORAGE_INFO_LOG_FILE}
		else
			umount -v $MOUNTED_DIR >> ${STORAGE_INFO_LOG_FILE}
			set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}MOUNTED" 1
			mount_dev $DEVNAME $MNT_DIR $ID_FS_TYPE >> ${STORAGE_INFO_LOG_FILE}
			RET=$?
			if [ $RET -eq 0 ]; then
				post_event "${MNT_DIR}" "${DEVNAME}" "$SDCARD_MOUNT"
				set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}MOUNTED" 1
			elif [ $RET -eq 5 ]; then
				# already mounted
				set_cfg_env $STORAGE_INFO_FILE "${ENV_NAME}MOUNTED" 1
			else
				log "${LINENO} [ERROR] mount_dev $DEVNAME $MNT_DIR $ID_FS_TYPE, RET=$RET"
				post_event "${MNT_DIR}" "${DEVNAME}" "$SDCARD_ERROR"
			fi
		fi
	fi
fi
