#!/bin/bash -e
source /etc/profile
#
# This script listens for the org.freedesktop.nm_dhcp_client signal.
# The signal is emitted every time dhclient-script would execute.
# It has the same contents as the environment passed to
# dhclient-script (8). Refer to manpage for variables of interest.
#

# "org.freedesktop.nm_dhcp_client" is an undocumented signal name,
# as far as I could tell. it is emitted by nm-dhcp-client.action,
# which is from the NetworkManager package source code.
# 

# detail: todo cleanup subprocess on exit. if the parent exits, 
#       the subprocess will linger until it tries to print
#       at which point it will get SIGPIPE and clean itself.
#       trap on bash's EXIT signal to do proper cleanup.


LogFolder=/var/log
[ ! -d $LogFolder ] && mkdir -p $LogFolder

DHCPCEVT_LOGFILE=${LogFolder}/dhcpc.log
DHCPCRENEWAL_LOGFILE=${LogFolder}/dhcpc.renewal
DHCPIP_LOGFILE=${LogFolder}/dhcpip.log

mkfifo /tmp/monitor-nm-change

(
	dbus-monitor --system "type='signal',interface='org.freedesktop.NetworkManager.DHCP4Config'"
) > /tmp/monitor-nm-change &

exec </tmp/monitor-nm-change
rm /tmp/monitor-nm-change

while read EVENT; do
	#change this condition to the event you're interested in
	if echo "$EVENT" | grep -q "PropertiesChanged"; then
		# do something interesting
		echo "current ip addresses:"
		ip addr show | grep inet
		# Make mail-body
		touch $DHCPIP_LOGFILE
		echo > $DHCPIP_LOGFILE

		for interface in eth0 wlan0
		do
			if [ $(ip addr | grep global | grep -c "inet.*$interface") -ne 0 ]; then
				echo "[`/bin/date +"%Y/%m/%d %H:%M:%S"`] DHCP4Config PropertiesChanged" > $DHCPCRENEWAL_LOGFILE
				echo "New DHCP IP Address : $(ip addr | grep global | grep $interface | awk '{print $2}')" >> $DHCPIP_LOGFILE
				MAIL_SUBJECT="New DHCP IP Address"
				MAIL_CFGFILE=/etc/sysconfig/netreport.conf
				/usr/sbin/smail "$MAIL_SUBJECT" "$DHCPIP_LOGFILE" "$MAIL_CFGFILE" &
			fi

		done
	fi
done