#!/bin/sh
#/opt/nss/bin/copy_n_fwupdate.sh

FIRMWARE_DIR=$1
source /etc/profile
if ! [ "$1" ]; then
	echo "Usage: $0 <firmware file's full path>"
	exit 1;
fi

function GetRootFSFreeSize() {
	fs_name="rootfs"
	df | grep -q $fs_name
	if [ $? -ne 0 ]; then # Can't find Filesystem
		return 0
	fi
	FREE_MB_STR=`df -m | grep $fs_name | awk '{printf $4}'`
	FREE_MB=$(printf "%d" $(echo "$FREE_MB_STR" | awk -F '.' '{printf $1}')) 
	return $(($FREE_MB))
}

function GetFileSizeMb() {
	_filename=$1
	_filesize_b=`ls -al ${_filename} | awk '{printf $5}'`
	if [[ $_filesize_b -ge 1024 ]]; then
		_filesize_kb=$(($_filesize_b / 1024))
		_filesize_mb=$(($_filesize_kb / 1024)) 
		_filesize_mb=$(($_filesize_mb + 1)) 
	else
		_filesize_mb=$((0))
	fi
	return $(($_filesize_mb))
}

check_firmware_version(){
	source /etc/system.info
	new_firmware_version=$(echo $1 | grep -o '[0-9].[0-9][0-9].[0-9][0-9][0-9]')
	cur_firmware_version=$(echo $SYS_VER);
	new_major=$(echo $new_firmware_version | grep -o '^[0-9].' | grep -o '^[0-9]')
	new_minor=$(echo $new_firmware_version | grep -o '.[0-9][0-9].' | grep -o '[0-9][0-9]')
	new_build=$(echo $new_firmware_version | grep -o '.[0-9][0-9][0-9]' | grep -o '[0-9][0-9][0-9]')
	old_major=$(echo $cur_firmware_version | grep -o '^[0-9].' | grep -o '^[0-9]')
	old_minor=$(echo $cur_firmware_version | grep -o '.[0-9][0-9].' | grep -o '[0-9][0-9]')
	old_build=$(echo $cur_firmware_version | grep -o '.[0-9][0-9][0-9]' | grep -o '[0-9][0-9][0-9]')
	new_major=$(echo $((${new_major#0})))
	new_minor=$(echo $((${new_minor#0})))
	new_build=$(echo $((${new_build#0})))
	old_major=$(echo $((${old_major#0})))
	old_minor=$(echo $((${old_minor#0})))
	old_build=$(echo $((${old_build#0})))

	if [ $new_build -gt $old_build -o $new_minor -gt $old_minor -o $new_major -gt $old_major ]; then
		echo "$new_major.$new_minor.$new_build != $old_major.$old_minor.$old_build"
		return 1;
	else
		echo "$new_major.$new_minor.$new_build == $old_major.$old_minor.$old_build"
		return 0;
	fi
}

check_firmware_version "$FIRMWARE_DIR"; [ $? -eq 0 ] && exit 0

GetRootFSFreeSize; FS_FREE_MB=$?
GetFileSizeMb "$FIRMWARE_DIR"; FILE_SIZE_MB=$?
if [ $FILE_SIZE_MB -ge 10 -a $FS_FREE_MB -ge $FILE_SIZE_MB ]; then
	echo "[  OK  ] $FS_FREE_MB > $FILE_SIZE_MB"
else
	echo "[FAILED] $FS_FREE_MB <= $FILE_SIZE_MB"
	echo "[REMOVE] Old Firmwares in /root/"
	for i in `ls /root/rf*`; do
		rm -vf $i
	done
fi
# check againe
GetRootFSFreeSize; FS_FREE_MB=$?
if [ $FILE_SIZE_MB -ge 10 -a $FS_FREE_MB -ge $FILE_SIZE_MB ]; then
	echo "[  OK  ] $FS_FREE_MB > $FILE_SIZE_MB"
else
	echo "[FAILED] $FS_FREE_MB <= $FILE_SIZE_MB"
	exit 1;
fi

ORG_MD5=`md5sum "${FIRMWARE_DIR}" | awk '{printf $1}'`
rgb_led -c w -b 50 -v 0
cp -av "${FIRMWARE_DIR}" /root/
sync
if [ $? -ne 0 ]; then 
	echo "usb firmware copy error!!"
	rgb_led -c w -v 0
fi
rgb_led -c w -b 500 -v 0
sync
sleep 2
NEW_MD5=`md5sum "$(ls /root/rf_*)" | awk '{printf $1}'`
if [ "$ORG_MD5" != "$NEW_MD5" ]; then
	ls -al ${FIRMWARE_DIR}
	ls -al /root/rf_*
	rm /root/rf_*
	reboot
	exit 0
fi

if [ $? -eq 0 ]; then
	sync
	nconfsave
	sync
	fwupdatepost.sh "$(ls /root/rf_*)"
	rgb_led -c w -v 1
	reboot
fi
