#!/bin/sh
 
source /etc/profile    

function load_i2c_rtc_pcf8563 () {
	modprobe rtc-pcf8563
	# /bin/echo pcf8563 0x51 > /sys/class/i2c-dev/i2c-0/device/new_device
}

function load_gpio_rtc_nju6350 () {
	insmod /lib/modules/3.10.104/sylinux/char/nju6350.ko
}

function load_default_rtc_module () {
	load_i2c_rtc_pcf8563;
}

function remove_rtc_module () {
	lsmod | grep -q nju6350
	if [ $? -eq 0 ]; then
		rmmod nju6350
	fi

	lsmod | grep -q pcf8563
	if [ $? -eq 0 ]; then
		rmmod pcf8563
	fi
}

function check_sys_date () {
	local current_date=`date +'%Y/%m/%d'`
	local sys_date=`cat /etc/system.info.base | grep SYS_DATE | awk -F'=' '{print $2}'`
	if [[ "$current_date" < "$sys_date" ]]; then
			echo "Invalid date. Be updated to $sys_date"
			date -s "${sys_date//\//-} `date +'%H:%M:%S'`"
			hwclock -w
	fi
}

if [ "$1" == "-r" ]; then
	remove_rtc_module;
	exit 0
fi

RTC_PNCODE=$(spcp 37 1)
[ "$RTC_PNCODE" == "" ] && exit 1

case "$RTC_PNCODE" in
	"0" )
		load_default_rtc_module;
		;;
	"P" )
		load_i2c_rtc_pcf8563;
		;;
	"G" )
		load_gpio_rtc_nju6350;
		;;
	* )
		echo "Unknown RTC_PNCODE=$RTC_PNCODE, try to load default RTC driver"
		load_default_rtc_module;
		;;
esac

hwclock -s
check_sys_date

exit 0

