#!/bin/sh
###################
# fw_init_stream.sh
###################
source /etc/profile

#=============================================================================
# TEST_IMAGE_IAV_READY defined and used in followed files
#   s3l_linux_sdk/ambarella/packages/img_mw/mw/arch_s3l/src/mw_netlink.c
#   s3l_linux_sdk/ambarella/app/utility/amb_scripts/fw_init_stream.sh
#   s3l_linux_sdk/ambarella/fwapp/ipcam/fwencd/fwencd.c
TEST_IMAGE_IAV_READY=/tmp/iav_ready
#=============================================================================

function wait_until_iav_ready() {
	while [ ! -f $TEST_IMAGE_IAV_READY ]; do
		echo "Wait iav netlink ready flag file..."
		sleep 1
	done
	sleep 1
}

function source_sensor_pncode() {
	[ -f /var/log/fw_sensor_pncode ] && source /var/log/fw_sensor_pncode
}

function guard_vsync_loss() {
	/usr/local/bin/guard_vsync_loss &
}

function set_sensor_setting() {
	case "$FW_SENSOR" in
		7A)
			ENC_SETTING="--imx322_2M" ;;
		7B)
			ENC_SETTING="--imx123_3M" ;;
		7C) # reserve
			ENC_SETTING="--imx123_2M" ;;
		7J)
			ENC_SETTING="--imx123_2M_60fps" ;;			
		7D)
			ENC_SETTING="--imx290" ;;
		7Y)
			ENC_SETTING="--imx290_2M_1080P_DUAL" ;;
		7E)
			ENC_SETTING="--imx290" ;;
			#ENC_SETTING="--imx291" ;;
		7F)
			ENC_SETTING="--imx326_5M" ;;
		7G)
			ENC_SETTING="--imx326_4M_0101" ;;
		7H)
			ENC_SETTING="--imx326_4M_1609" ;;
		7L)
			ENC_SETTING="--imx178_6M_3072" ;;
		7O)
			ENC_SETTING="--imx178_4M_2688_1520" ;;
		7M)
			ENC_SETTING="--imx178_5M_2592" ;;
		7N)
			ENC_SETTING="--imx178_2M_1920" ;;
		7R)
			ENC_SETTING="--imx385_2M_mipi" ;;
		7r)
			ENC_SETTING="--imx385_2M_mipi_60fps" ;;
		7[Uu])
			ENC_SETTING="--imx250_4M" ;;
		7[Ww])
			ENC_SETTING="--imx250_5M" ;;
		7[Vv])
			ENC_SETTING="--imx250_2M" ;;
		7[Xx])
			ENC_SETTING="--imx250_3M" ;;
		7Z)
			ENC_SETTING="--imx385_2M_mipi_1080_DUAL" ;;
		0[Nn] )
			ENC_SETTING="--bt656_ntsc" ;;
		0[Pp] )
			ENC_SETTING="--bt656_pal" ;;
		3[U])   # 1920x1080p60(1080p60)
			ENC_SETTING="--adv7441a_cbcr_swap" ;;
		3[u])   # 800x600(svga)
			ENC_SETTING="--adv7441a_cbcr_swap_svga" ;;
		3[W])   # 1920x1080i60(1080i60)
			ENC_SETTING="--adv7441a_cbcr_swap_1080i60" ;;
		3[X])   # 1280x720(720p)
			ENC_SETTING="--adv7441a_cbcr_swap_720p" ;;
		3[Y])   # 1280x1024(sxga)
			ENC_SETTING="--adv7441a_cbcr_swap_sxga" ;;			
		3[Q])   # 1024x768(xga)
			ENC_SETTING="--adv7441a_cbcr_swap_xga" ;;	
		3[O] )
			ENC_SETTING="--bt1120_yc_swap_yuv1080p30" ;;
		3[P] | 3[45])	# 2560x1440.
			ENC_SETTING="--bt1120_1440" ;;
		3[g] )  # 720p50_yc_swap for Bic Inform 
			ENC_SETTING="--bt1120_yc_swap_yuv720p50" ;;
		3[d] )
			ENC_SETTING="--bt1120_yc_swap_yuv1080p30" ;;
		3[C] )
			#ENC_SETTING="--bt1120_yc_swap_yuv1080p30_dual" ;;	
			ENC_SETTING="--bt1120_yc_swap_yuv1080p30" ;;	
		3[D] )
			ENC_SETTING="--bt1120_yc_swap_yuv1080p60" ;;	
		3[b] )
			ENC_SETTING="--bt1120_yc_swap_yuv1080p25" ;;				
        0o ) #UFINE 720p 30fps (GPI-360)
            # 0o
            ENC_SETTING="--bt1120_yc_swap_yuv720p30";;
		3[FG6] )	# Wonwoo 4M PTZ 2560x1440 30fps(M9 Chipset) #FS
			# 3F 3G 36 
			ENC_SETTING="--bt1120_yc_swap_yuv1440p30" ;;	
		3[f8] )	# Wonwoo 4M PTZ 2560x1440 25fps(M9 Chipset)
			# 3f 38
			ENC_SETTING="--bt1120_yc_swap_yuv1440p25" ;;
		4[E] )	# Wonwoo 4M PTZ 2560x1440 30fps(MDIN) 
			# 4E 
			ENC_SETTING="--bt1120_yc_swap_yuv1440p30" ;;	
		4[e] )	# Wonwoo 4M PTZ 2560x1440 25fps(MDIN)
			# 4e
			ENC_SETTING="--bt1120_yc_swap_yuv1440p25" ;;
		3[a] )	# Wonwoo 2M PTZ 1080P 30fps(MDIN Chipset)
			# 3a
			ENC_SETTING="--bt1120_yc_swap_yuv1080p30" ;;	
		3[x] )	# Wonwoo 2M PTZ 1080P 25fps(MDIN Chipset)
			# 3x
			ENC_SETTING="--bt1120_yc_swap_yuv1080p25" ;;	
		5[U])   # 1920x1080p60(1080p60)
			ENC_SETTING="--adv7611_cbcr_swap" ;;
		5[u])   # 800x600(svga)
			ENC_SETTING="--adv7611_cbcr_swap_svga" ;;			
		5[W])   # 1920x1080i60(1080i60)
			ENC_SETTING="--adv7611_cbcr_swap_1080i60" ;;
		5[X])   # 1280x720(720p)
			ENC_SETTING="--adv7611_cbcr_swap_720p" ;;
		5[Y])   # 1280x1024(sxga)
			ENC_SETTING="--adv7611_cbcr_swap_sxga" ;;			
		5[Q])   # 1024x768(xga)
			ENC_SETTING="--adv7611_cbcr_swap_xga" ;;	
		1[g] )
			ENC_SETTING="--bt1120_yc_swap_yuv1080p30" ;;	
		1[X] )
			ENC_SETTING="--bt601_yc_swap_yuv1080p30" ;;	
		1[C] )	# Wonwoo 2M PTZ 1080p 30fps
            ENC_SETTING="--bt1120_yc_swap_yuv1080p30" ;;			
		1[c] )	# Wonwoo 2M PTZ 1080p 25fps
            ENC_SETTING="--bt1120_yc_swap_yuv1080p25" ;;	
		3[yz] | 4[0] )	# IndusVision PTZ / Seyeon PTZ 2M 30fps
            ENC_SETTING="--bt1120_yc_swap_yuv1080p30" ;;			
		3[pq] )	# KTnC 2M PTZ 1080p 30fps
			ENC_SETTING="--bt1120_yc_swap_yuv1080p30" ;;			
		2[X] )
            ENC_SETTING="--bt1120_yc_swap_yuv1080p60" ;;			
		2[A] )	# DongYang Unitech PTZ 1080p 60fps
            ENC_SETTING="--bt1120_yc_swap_yuv1080p60" ;;			
		2[a] )	# DongYang Unitech PTZ 1080p 50fps
            ENC_SETTING="--bt1120_yc_swap_yuv1080p50" ;;
		2[B] )	# Sony PTZ 1080p 60fps
            ENC_SETTING="--bt1120_yc_swap_yuv1080p60" ;;			
		2[b] )	# Sony PTZ 1080p 50fps
            ENC_SETTING="--bt1120_yc_swap_yuv1080p50" ;;	
		2[C] )	# Wonwoo 2M PTZ 1080p 60fps(M8 Chipset).
            ENC_SETTING="--bt1120_yc_swap_yuv1080p60" ;;		
		2[c] )	# Wonwoo 2M PTZ 1080p 50fps(M8 Chipset).
            ENC_SETTING="--bt1120_yc_swap_yuv1080p50" ;;	
		2[D] ) # Wonwoo 2M PTZ 1080p 60fps(M9 Chipset)	
            ENC_SETTING="--bt1120_yc_swap_yuv1080p60" ;;
		2[d] ) # Wonwoo 2M PTZ 1080p 50fps(M9 Chipset)	
            ENC_SETTING="--bt1120_yc_swap_yuv1080p50" ;;
		2[E] ) # Wonwoo 2M PTZ 1080p 60fps(MDIN Chipset)	
            ENC_SETTING="--bt1120_yc_swap_yuv1080p60" ;;
		2[e] ) # Wonwoo 2M PTZ 1080p 50fps(MDIN Chipset)	
            ENC_SETTING="--bt1120_yc_swap_yuv1080p50" ;;
		33 )
			ENC_SETTING="--bt1120_yc_swap_yuv1080p25" ;;
        10 ) #TBT Thermal Camera 480p 30fps(OSD Control)
            # 10
            ENC_SETTING="--bt656_ntsc30" ;;
        20 ) #TBT Thermal Camera 480p 60fps(OSD Control)
            # 20
            ENC_SETTING="--bt656_ntsc60" ;;
        12 ) #TBT Thermal Camera 576p 25fps(OSD Control)
            # 12
            ENC_SETTING="--bt656_pal25" ;;
        22 ) #TBT Thermal Camera 576p 50fps(OSD Control)
            # 22
            ENC_SETTING="--bt656_pal50" ;;
        3v ) #TBT Thermal Camera 720p 30fps(OSD Control)
            # 3v
            ENC_SETTING="--bt1120_yc_swap_yuv720p30" ;;
        3w ) #TBT Thermal Camera 720p 25fps(OSD Control)
            # 3w
            ENC_SETTING="--bt1120_yc_swap_yuv720p25" ;;
		3[T]) #BT.601 - 720P TBT with IBDR.
			# 3T
			ENC_SETTING="--bt601_yc_swap_yuv720p30" ;;
        3[Ss] ) #TBT Thermal Camera 720p 30fps(OSD Control)
            # 3S, 3s
            ENC_SETTING="--bt1120_yc_swap_yuv720p30" ;;
        3o | 4o ) #KT&C 720p VISCA 30fps
            # 3o
            ENC_SETTING="--bt1120_yc_swap_yuv720p30" ;;
		* )
			ENC_SETTING="default" ;;
	esac
}

function execute_test_encode() {
	case $ENC_SETTING in
		--imx322_2M )
			/usr/local/bin/test_encode -i 1080p -f 30 -V 480i --cvbs ;;
		--imx123_2M )
			/usr/local/bin/test_encode -i 1080p -f 30 -V 480i --cvbs ;;
		--imx123_2M_60fps )
			/usr/local/bin/test_encode -i 1080p -f 60 -V 480i --cvbs ;;			
		--imx291 )
			/usr/local/bin/test_encode -i 1080p -f 30 -V 480i --cvbs ;;
		--imx290 )
			/usr/local/bin/test_encode -i 1080p -f 30 -V 480i --cvbs -X --bsize 1080p --bmaxsize 1080p -Y --btype enc --bsize 352x288 --bmaxsize 352x288 -J --btype enc --bsize 480p --bmaxsize 480p ;;
			#/usr/local/bin/test_encode -i 1080p -f 30 -V 480i --cvbs -X --bsize 1080p --bmaxsize 1080p -Y --btype enc --bsize 352x288 --bmaxsize 352x288 -J --btype enc --bsize 480p --bmaxsize 480p -A --max-gop-M 1 -M 1 --smaxsize 1080p -B --max-gop-M 1 -M 1 --smaxsize 480p -C --max-gop-M 1 -M 1 --smaxsize 352x288 -A -h 1080p -b 0 -e -B -h 480p -b 2 -e -C -h 352x288 -b 1 -e ;;
		--imx290_2M_1080P_DUAL )
			#/usr/local/bin/test_encode -i 1080p -f 30 -V 480i --cvbs ;;		
			/usr/local/bin/test_encode -i 1080p -f 30 -V 480i --cvbs --enc-mode 0 -X --bsize 1080p --bmaxsize 1080p -A --smaxsize 1080p -h 1080p -b 0 -B --smaxsize 1080p -m 1080p -b 0 -Y --btype off -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p -C --smaxsize 480p -h 480p -b 3 ;; 
		--imx250_2M )
			/usr/local/bin/test_encode -i 1080p -f 30 -V 480i --cvbs ;;
		--imx250_3M )
			/usr/local/bin/test_encode -i 2048x1536 -f 30 -V 480i --cvbs ;;	
		--imx250_4M )
			/usr/local/bin/test_encode -i 2304x1728 -f 30 -V 480i --cvbs ;;	
		--imx250_5M )
			/usr/local/bin/test_encode -i 2432x2048 -f 30 -V 480i --cvbs ;;	
		--imx385_2M_mipi )
			/usr/local/bin/test_encode -i 1080p -f 30 -V 480i --cvbs ;;
		--imx385_2M_mipi_60fps )
			/usr/local/bin/test_encode -i 1080p -f 60 -V 480i --cvbs ;;
		--imx385_2M_mipi_1080_DUAL )			
			#/usr/local/bin/test_encode -i 1920x1080 -f 30 -V 480i --cvbs ;;
			/usr/local/bin/test_encode -i 1080p -f 30 -V 480i --cvbs --enc-mode 0 -X --bsize 1080p --bmaxsize 1080p -A --smaxsize 1080p -h 1080p -b 0 -B --smaxsize 1080p -m 1080p -b 0 -Y --btype off -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p -C --smaxsize 480p -h 480p -b 3 ;; 
		--imx326_5M )
			/usr/local/bin/test_encode -i 2592x1944 -f 30 -V 480i --cvbs ;;
		--imx326_4M_1609 )
			/usr/local/bin/test_encode -i 2688x1520 -f 30 -V 480i --cvbs ;;
		--imx326_4M_0101 )
			/usr/local/bin/test_encode -i 2048x2048 -f 30 -V 480i --cvbs ;;
		--imx178_6M_3072 )
			#/usr/local/bin/test_encode -i 3072x2048 -f 15 -V 480i --cvbs ;;
			/usr/local/bin/test_encode -i 3072x2048 -f 15 -V 480i --cvbs -X --bsize 3072x2048 --bmaxsize 3072x2048 -A --smaxsize 3072x2048 -h 3072x2048 -b 0 ;;
		--imx178_5M_2592 )
			#/usr/local/bin/test_encode -i 2592x1944 -f 15 -V 480i --cvbs ;;
			/usr/local/bin/test_encode -i 2592x1944 -f 15 -V 480i --cvbs -X --bsize 2592x1944 --bmaxsize 2592x1944 -A --smaxsize 2592x1944 -h 2592x1944 -b 0 ;;
		--imx178_4M_2688_1520 )
			#/usr/local/bin/test_encode -i 2688x1520 -f 30 -V 480i --cvbs ;;
			/usr/local/bin/test_encode -i 2688x1520 -f 30 -V 480i --cvbs -X --bsize 2688x1520 --bmaxsize 2688x1520 -A --smaxsize 2688x1520 -h 2688x1520 -b 0 ;;
			#/usr/local/bin/test_encode -i 2688x1520 -f 30 -V 480i --cvbs -X --bsize 2688x1520 --bmaxsize 2688x1520 -A --smaxsize 2688x1520 -h 2688x1520 -b 0 -Y --btype enc -K --btype enc --bsize 320x240 --bmaxsize 320x240 -B --smaxsize 320x240p -h 320x240 -b 2 ;;
		--ov10823 )
			/usr/local/bin/test_encode -i 3840x2160 -f 15 -V 480i --cvbs ;;
		--imx178_2M_1920 )
			/usr/local/bin/test_encode -i 1920x1080 -f 30 -V 480i --cvbs ;;		
		--adv7441a_cbcr_swap )
			/usr/local/bin/test_encode -i auto -J --btype off ;;
			#/usr/local/bin/test_encode -i auto -v480p --lcd digital601 -X --bsize 1080p --bmaxsize 1080p -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p ;;
		--adv7441a_cbcr_swap_1080i60 )
			/usr/local/bin/test_encode -i auto -v720p --lcd digital601 -X --bsize 1920x544 --bmaxsize 1920x544 -Y --bsize 720x480 --bmaxsize 720x480 -J --btype off -K --btype prev --bsize 480p --bmaxsize 480p ;;
		--adv7441a_cbcr_swap_720p )
			/usr/local/bin/test_encode -i auto -v480p --lcd digital601 -X --bsize 720p --bmaxsize 720p -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p ;;					
		--adv7441a_cbcr_swap_sxga )
			/usr/local/bin/test_encode -i auto -v480p --lcd digital601 -X --bsize 1280x1024 --bmaxsize 1280x1024 -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p ;;
		--adv7441a_cbcr_swap_xga )
			/usr/local/bin/test_encode -i auto -v480p --lcd digital601 -X --bsize 1024x768 --bmaxsize 1024x768 -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p ;; 
		--adv7441a_cbcr_swap_svga )
			/usr/local/bin/test_encode -i auto -v480p --lcd digital601 -X --bsize 800x600 --bmaxsize 800x600 -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p ;; 
		--adv7611_cbcr_swap )
			/usr/local/bin/test_encode -i auto -J --btype off ;;
			#/usr/local/bin/test_encode -i auto -v480p --lcd digital601 -X --bsize 1080p --bmaxsize 1080p -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p ;;
		--adv7611_cbcr_swap_1080i60 )
			/usr/local/bin/test_encode -i auto -v720p --lcd digital601 -X --bsize 1920x544 --bmaxsize 1920x544 -Y --bsize 720x480 --bmaxsize 720x480 -J --btype off -K --btype prev --bsize 480p --bmaxsize 480p ;;
		--adv7611_cbcr_swap_720p )
			/usr/local/bin/test_encode -i auto -v480p --lcd digital601 -X --bsize 720p --bmaxsize 720p -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p ;;					
		--adv7611_cbcr_swap_sxga )
			/usr/local/bin/test_encode -i auto -v480p --lcd digital601 -X --bsize 1280x1024 --bmaxsize 1280x1024 -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p ;;
		--adv7611_cbcr_swap_xga )
			/usr/local/bin/test_encode -i auto -v480p --lcd digital601 -X --bsize 1024x768 --bmaxsize 1024x768 -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p ;; 
		--adv7611_cbcr_swap_svga )
			/usr/local/bin/test_encode -i auto -v480p --lcd digital601 -X --bsize 800x600 --bmaxsize 800x600 -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p ;; 
		--bt656_ntsc )
			/usr/local/bin/test_encode -i 0 -f 30 -V480i --cvbs -X --bsize 704x480 --bmaxsize 704x480 -Y --bsize 704x480 --bmaxsize 704x480 -J --btype enc --bsize 704x480 --bmaxsize 704x480 -K --btype enc --bsize 704x480 --bmaxsize 704x480 ;;
		--bt656_ntsc30 )
			/usr/local/bin/test_encode -i 0 -f 30 -V480i --cvbs -X --bsize 704x480 --bmaxsize 704x480 -Y --bsize 704x480 --bmaxsize 704x480 -J --btype enc --bsize 704x480 --bmaxsize 704x480 -K --btype enc --bsize 704x480 --bmaxsize 704x480 ;;
		--bt656_ntsc60 )
			/usr/local/bin/test_encode -i 0 -f 60 -V480i --cvbs -X --bsize 704x480 --bmaxsize 704x480 -Y --bsize 704x480 --bmaxsize 704x480 -J --btype enc --bsize 704x480 --bmaxsize 704x480 -K --btype enc --bsize 704x480 --bmaxsize 704x480 ;;
		--bt656_pal )
			/usr/local/bin/test_encode -i 0 -f 30 -V480i --cvbs -X --bsize 704x576 --bmaxsize 704x576 -Y --bsize 704x576 --bmaxsize 704x576 -J --btype enc --bsize 704x576 --bmaxsize 704x576 -K --btype enc --bsize 704x576 --bmaxsize 704x576 ;;
		--bt656_pal25 )
			/usr/local/bin/test_encode -i 0 -f 25 -V480i --cvbs -X --bsize 704x576 --bmaxsize 704x576 -Y --bsize 704x576 --bmaxsize 704x576 -J --btype enc --bsize 704x576 --bmaxsize 704x576 -K --btype enc --bsize 704x576 --bmaxsize 704x576 ;;
		--bt656_pal50 )
			/usr/local/bin/test_encode -i 0 -f 50 -V480i --cvbs -X --bsize 704x576 --bmaxsize 704x576 -Y --bsize 704x576 --bmaxsize 704x576 -J --btype enc --bsize 704x576 --bmaxsize 704x576 -K --btype enc --bsize 704x576 --bmaxsize 704x576 ;;
		--bt1120_1440 )
			/usr/local/bin/test_encode -i auto -v480p --lcd digital601 -X --bsize 2560x1440 --bmax 2560x1440 -A -h 2560x1440 --smax 2560x1440 -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p ;;
		--bt1120_yc_swap_yuv720p25 )
			/usr/local/bin/test_encode -i 0 -f 25 -V576i --cvbs -X --bsize 720p --bmaxsize 720p ;;
		--bt1120_yc_swap_yuv720p30 )
			/usr/local/bin/test_encode -i 0 -f 30 -V480i --cvbs -X --bsize 720p --bmaxsize 720p ;;
		--bt1120_yc_swap_yuv720p50 )
			/usr/local/bin/test_encode -i 0 -f 50 -V576i --cvbs -X --bsize 720p --bmaxsize 720p ;;
		--bt1120_yc_swap_yuv720p60 )
			/usr/local/bin/test_encode -i 0 -f 60 -V480i --cvbs -X --bsize 720p --bmaxsize 720p ;;		
		--bt1120_yc_swap_yuv1080p30 )
			/usr/local/bin/test_encode -i 0 -f 30 -V480i --cvbs -X --bsize 1080p --bmaxsize 1080p ;;	
		--bt1120_yc_swap_yuv1080p30_dual )
			#/usr/local/bin/test_encode -i 0 -f 30 -V480i --cvbs -X --bsize 1080p --bmaxsize 1080p ;;	
			/usr/local/bin/test_encode -i 0 -f 30 -V480i --cvbs --enc-mode 0 -X --bsize 1080p --bmaxsize 1080p -A --smaxsize 1080p -h 1080p -b 0 -B --smaxsize 1080p -m 1080p -b 0 -Y --btype off -J --btype off -K --btype enc --bsize 320x240 --bmaxsize 320x240 -C --smaxsize 320x240 -h 320x240 -b 3 ;;
		--bt1120_yc_swap_yuv1080p25 )
			/usr/local/bin/test_encode -i 0 -f 25 -V576i --cvbs -X --bsize 1080p --bmaxsize 1080p ;;	
		--bt1120_yc_swap_yuv1080p60 )
			/usr/local/bin/test_encode -i 0 -f 60 -V480i --cvbs -X --bsize 1080p --bmaxsize 1080p ;;
		--bt1120_yc_swap_yuv1080p50 )
			/usr/local/bin/test_encode -i 0 -f 50 -V576i --cvbs -X --bsize 1080p --bmaxsize 1080p ;;
		--bt1120_yc_swap_yuv1440p30 )
			/usr/local/bin/test_encode -i auto -f 30 -v480i --lcd digital601 -X --bsize 2560x1440 --bmax 2560x1440 -A -h 2560x1440 --smax 2560x1440 -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p ;;
		--bt1120_yc_swap_yuv1440p25 )
			/usr/local/bin/test_encode -i auto -f 25 -v576i --lcd digital601 -X --bsize 2560x1440 --bmax 2560x1440 -A -h 2560x1440 --smax 2560x1440 -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p ;;
		--bt601_yc_swap_yuv720p30 )
			/usr/local/bin/test_encode -i 0 -f 30 -V480i --cvbs -X --bsize 720p --bmaxsize 720p ;;
		--bt601_yc_swap_yuv1080p30 )	
			/usr/local/bin/test_encode -i 0 -f 30 -V480i --cvbs -X --bsize 1080p --bmaxsize 1080p ;;	
		* )
			/usr/local/bin/test_encode -i 0 -f 30 -V480i --cvbs -X --bsize 1080p --bmaxsize 1080p -A -h 1080p --smaxsize 1080p -Y --bsize 320x240 --bmaxsize 320x240 -J --btype off -K --btype enc --bsize 480p --bmaxsize 480p;;
	esac
}

function check_if_success_to_test_encoded() {
	local trials_count=$1
	local count=0
	while [ $count -lt $trials_count ]; do
		sleep 1
		if [ -f /tmp/amba_exposure.conf ] && [ -f /tmp/amba_exposure.complete ]; then
			return 0
		fi
		echo "[$SCRIPT_NAME:${LINENO}] not test_encode done yet. one more try..."
#		execute_test_encode
		((count += 1))
	done
	echo "[$SCRIPT_NAME:${LINENO}] fail to test encode."
	return 1
}

function check_pncode_for_eha() {
case "$FW_SENSOR" in
	3[QWXYUu])
		return 1;;
	*)
		return 0;;
esac
}

function retry_test_encode_and_check() {

	if [ $retval2 -eq 1 ]; then
		execute_test_encode
		check_if_success_to_test_encoded 5
		echo "Done retrying for EHA."
	fi
}

function do_main() {
	wait_until_iav_ready
	source_sensor_pncode
	set_sensor_setting
	guard_vsync_loss
	execute_test_encode
	check_if_success_to_test_encoded 5
	retval1=$?
	if [ $retval1 -eq 1 ]; then
		check_pncode_for_eha
	fi
	retval2=$?
	retry_test_encode_and_check	
}
###################

SCRIPT_NAME=`basename $0`
do_main
# CVBS buffer initialize
# /usr/local/bin/test_encode -J --btype off -K --bmaxsize 720x480 --bsize 720x480 --btype prev --vout-swap 1
