#!/bin/sh

DEFAULT_CONFIG=/etc/default_conf.tgz

[ -f "$DEFAULT_CONFIG" ] || { echo "[$0]:$DEFAULT_CONFIG is not exist!!";  exit 0; }

source /usr/local/bin/fw_common.sh

function backup_security_log() {
	$TAR czf $SECURE_LOG_BACKUP -C `dirname $FW_SECURE_LOG_DIR` `basename $FW_SECURE_LOG_DIR`
}

function restore_security_log() {
	if [ -f $SECURE_LOG_BACKUP ]; then
		$TAR xzf $SECURE_LOG_BACKUP -C `dirname $FW_SECURE_LOG_DIR`
	fi
}

function init_upnp_cfg() {
	local security_option=$1
	local default_value="yes"
	if [ "$security_option" -ne 0 ]; then
		default_value="no"
	fi
	local upnp_cfg_file=/opt/nss/etc/fwupnp.conf
	if [ -f $upnp_cfg_file ]; then
		$SED -i 's|UPNP_DEVICE_ENABLE=".*"|UPNP_DEVICE_ENABLE="'$default_value'"|' $upnp_cfg_file
	fi
}

function check_ftp_telnet_conf() {
	local ftp_services_to_remove="ftp.socket"
	local telnet_services_to_remove="telnet.socket"

	if [ ! -f "/etc/systemd/system/sockets.target.wants/ftp.socket" ];then
		for s in $ftp_services_to_remove; do
			local is_active=`$SYSTEMCTL status $s | $GREP "Active: active" | $WC -l`
			if [ $is_active -ne 0 ]; then
				$SYSTEMCTL stop $s
				$SYSTEMCTL disable $s
			fi
		done
	fi
	
	if [ ! -f "/etc/systemd/system/sockets.target.wants/telnet.socket" ];then
		for s in $telnet_services_to_remove; do
			local is_active=`$SYSTEMCTL status $s | $GREP "Active: active" | $WC -l`
			if [ $is_active -ne 0 ]; then
				$SYSTEMCTL stop $s
				$SYSTEMCTL disable $s
			fi
		done
	fi
}

SECURE_LOG_BACKUP="/tmp/`basename $FW_SECURE_LOG_DIR`.tgz"
SECURE_OPTION=`$SPCP 38 1`

SYCONF_DIR=/etc/sy_conf
echo "SYCONF_DIR: $SYCONF_DIR"

backup_security_log

FILES_TO_COMPRESS="`${SYCONF_DIR}/cfglist2save all`"
# ${SYCONF_TMP_DIR}/cfglist2save all ${TMP_DIR}
pushd / > /dev/null
for i in $FILES_TO_COMPRESS; do
	[ -f "$i" ] && /bin/rm -f $i
	[ -d "$i" ] && /bin/rm -rf $i
done
mkdir -p ${SYCONF_DIR}
rm -f /opt/nss/etc/FwConf/FwCamCtlConf*.bin
/bin/tar xzf $DEFAULT_CONFIG -C /

restore_security_log
init_upnp_cfg $SECURE_OPTION
popd > /dev/null

# init oem default config

OEM_DEF_INIT_LOG=/etc/sysconfig/oem_def_init.log
rm -f $OEM_DEF_INIT_LOG
OEM_INIT_SH=/etc/oem_def_init.sh
if [ -x "$OEM_INIT_SH" ]; then
	$OEM_INIT_SH
fi

if [ -f /usr/local/bin/chg_default_pw.asp ]; then
	ln -nfs /usr/local/bin/chg_default_pw.asp /web/chg_default_pw.asp
fi

check_ftp_telnet_conf

sync
sleep 1
