#!/bin/sh

source /usr/local/bin/fw_common.sh

function backup_security_log() {
	$TAR czf $SECURE_LOG_BACKUP -C `dirname $FW_SECURE_LOG_DIR` `basename $FW_SECURE_LOG_DIR`
}

function restore_security_log() {
	if [ -f $SECURE_LOG_BACKUP ]; then
		$TAR xzf $SECURE_LOG_BACKUP -C `dirname $FW_SECURE_LOG_DIR`
	fi
}

function check_ftp_telnet_conf() {
	local ftp_services_to_remove="ftp.socket"
	local telnet_services_to_remove="telnet.socket"

	if [ ! -f "/etc/systemd/system/sockets.target.wants/ftp.socket" ];then
		for s in $ftp_services_to_remove; do
			local is_active=`$SYSTEMCTL status $s | $GREP "Active: active" | $WC -l`
			if [ $is_active -ne 0 ]; then
				$SYSTEMCTL stop $s
				$SYSTEMCTL disable $s
			fi
		done
	fi
	
	if [ ! -f "/etc/systemd/system/sockets.target.wants/telnet.socket" ];then
		for s in $telnet_services_to_remove; do
			local is_active=`$SYSTEMCTL status $s | $GREP "Active: active" | $WC -l`
			if [ $is_active -ne 0 ]; then
				$SYSTEMCTL stop $s
				$SYSTEMCTL disable $s
			fi
		done
	fi
}

#==============================================================================================================
# Extract default config file
#==============================================================================================================
DEFAULT_CONFIG=/etc/default_conf.tgz

SECURE_LOG_BACKUP="/tmp/`basename $FW_SECURE_LOG_DIR`.tgz"
backup_security_log

sync
FILES_TO_COMPRESS=`/etc/sy_conf/cfglist2save all`
[ -f "$DEFAULT_CONFIG" ] || exit 0
pushd / > /dev/null
for i in $FILES_TO_COMPRESS; do
	[ -f "$i" ] && /bin/rm -f $i
	[ -d "$i" ] && /bin/rm -rf $i
done
rm -f /opt/nss/etc/FwConf/FwCamCtlConf*.bin
/bin/tar xzf $DEFAULT_CONFIG -C /
sync
popd > /dev/null

#==============================================================================================================
# Init oem default config
#==============================================================================================================
OEM_DEF_INIT_LOG=/etc/sysconfig/oem_def_init.log
rm -f $OEM_DEF_INIT_LOG
OEM_INIT_SH=/etc/oem_def_init.sh
if [ -x "$OEM_INIT_SH" ]; then
	$OEM_INIT_SH
fi
/bin/sync

#==============================================================================================================
# Prepare Recovery Configuration 
#==============================================================================================================
RFS_CI_IMG=/mnt/rfs/ci.tar.gz
CI_IMG=/tmp/ci.tar.gz

DO_RECOVER_CI_IMG=0

# check if $RFS_CI_IMG exists
if [ -f $RFS_CI_IMG ]; then
	echo "$RFS_CI_IMG exists"
	/bin/gunzip -t $RFS_CI_IMG
	if [ $? -eq 0 ]; then
		echo "$RFS_CI_IMG is OK"
		cp -f $RFS_CI_IMG $CI_IMG
		DO_RECOVER_CI_IMG=1
	else
		echo "$RFS_CI_IMG is NG"
	fi
fi

# if no $RFS_CI_IMG, then read from sycfg partition
if [ "$DO_RECOVER_CI_IMG" -eq 0 ]; then
	echo "try to read cfg data from sycfg parition"
	PartitionName="sycfg"
	MtdNum=`cat /proc/mtd | grep $PartitionName | awk '{print $1}' | sed -e s/^mtd// | sed -e s/\://`
	CI_MTD=/dev/mtd${MtdNum}
	MTD_SIZE=`cat /proc/mtd| grep $PartitionName | awk '{printf $2}'`

	NANDDUMP=/mnt/rfs/usr/sbin/nanddump
	if [ ! -x $NANDDUMP ]; then
		NANDDUMP=/usr/sbin/nanddump
	fi
	echo "NANDDUMP: $NANDDUMP"
	$NANDDUMP --bb=skipbad -f $CI_IMG ${CI_MTD}
	/bin/gunzip -t $CI_IMG
	if [ $? -eq 0 ]; then
		DO_RECOVER_CI_IMG=1
	else
		echo
		printf "${YELLOW}**********************************${NC}\n"
		printf "[${YELLOW}WARN ${NC}] Fail to read backup cfg data from sycfg\n"
		printf "${YELLOW}**********************************${NC}\n"
		echo
	fi
fi

if [ $DO_RECOVER_CI_IMG -eq 1 ]; then
	/bin/tar xzf $CI_IMG -C /
	/bin/sync
	restore_security_log
fi

if [ -f /usr/local/bin/chg_default_pw.asp ]; then
	ln -nfs /usr/local/bin/chg_default_pw.asp /web/chg_default_pw.asp
fi

check_ftp_telnet_conf

sync
sleep 1
